
``wsq`` Python code is written and maintained by Olivier Heurtier.

WSQ compression/decompression algorithm was developed at the
National Institute of Standards and Technology (NIST) by employees of
the US Federal Government in the course of their official duties. It is not
subject to copyright protection and is in the public domain.
(See https://www.nist.gov/document/nigoslicdis061906pdf for more information)

Contributors
------------

- Oivier Heurtier <olivier.heurtier@idemia.com> `@olivier-heurtier-idemia <https://github.com/olivier-heurtier-idemia>`_

